@@ -5,17 +5,24 @@ module DiasporaFederation
     # @see Validators::PersonValidator
     class Person < Entity
       # @!attribute [r] guid
-      #   @see HCard#guid
+      #   This is just the guid. When a user creates an account on a pod, the pod
+      #   MUST assign them a guid - a random string of at least 16 chars.
+      #   @see Validation::Rule::Guid
       #   @return [String] guid
       property :guid
 
-      # @!attribute [r] diaspora_id
+      # @!attribute [r] author
       #   The diaspora ID of the person
+      #   @see Validation::Rule::DiasporaId
       #   @return [String] diaspora ID
-      property :diaspora_id, xml_name: :diaspora_handle
+      # @!attribute [r] diaspora_id
+      #   Alias for author
+      #   @see Person#author
+      #   @return [String] diaspora ID
+      property :author, alias: :diaspora_id, xml_name: :diaspora_handle
 
       # @!attribute [r] url
-      #   @see WebFinger#seed_url
+      #   @see Discovery::WebFinger#seed_url
       #   @return [String] link to the pod
       property :url
 
@@ -25,7 +32,7 @@ module DiasporaFederation
       entity :profile, Entities::Profile
 
       # @!attribute [r] exported_key
-      #   @see HCard#public_key
+      #   @see Discovery::HCard#public_key
       #   @return [String] public key
       property :exported_key
     end
